@@ -1,3 +1,7 @@
+# Copyright (c) 2024 Merlise Clyde and contributors to BAS. All rights reserved.
+# This work is licensed under a GNU GENERAL PUBLIC LICENSE Version 3.0
+# License text is available at https://www.gnu.org/licenses/gpl-3.0.html
+#
 normalize.initprobs.lm <- function(initprobs, p) {
   if (length(initprobs) != p) {
     stop(paste(
@@ -41,7 +45,7 @@ normalize.modelprior <- function(modelprior, p) {
 normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 
   if (is.null(n.models)) {
-    p = max(30, p)
+    p = max(25, p)
     n.models <- 2^(p - 1)
   }
   if (n.models > 2^(p - 1)) n.models <- 2^(p - 1)
@@ -165,6 +169,23 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' to modify the rate parameter in the gamma prior on g,  
 #' \deqn{1/g \sim G(1/2, n*\alpha/2)} so that
 #' \deqn{\beta \sim C(0, \sigma^2 \alpha (X'X/n)^{-1})}.
+#' If alpha = NULL, then the following defaults are used currently:
+#' \itemize{
+#' \item  "g-prior" = n,
+#' \item "hyper-g" = 3,
+#' \item "EB-local" = 2,
+#' \item "BIC" = n,
+#' \item "ZS-null" = 1,
+#' \item "ZS-full" = n,
+#' \item "hyper-g-laplace" = 3,
+#' \item "AIC" = 0,
+#' \item "EB-global" = 2,
+#' \item "hyper-g-n" = 3,
+#' \item "JZS" = 1,
+#' }
+#' Note that Porwal & Raftery (2022) recommend alpha = sqrt(n) for the g-prior
+#' based on extensive range of simulations and examples for comparing BMA.
+#' This will become the default in the future.
 #' @param modelprior A function for a family of prior distribution on the models.  Choices
 #' include \code{\link{uniform}} \code{\link{Bernoulli}} or
 #' \code{\link{beta.binomial}}, \code{\link{tr.beta.binomial}},
@@ -219,7 +240,6 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' algorithm, with if `importance.sampling = TRUE`  uses importance sampline 
 #' combined with Horiwitz-Thompson estimates of posterior model and inclusion
 #' probabilities.
-#' can be 
 #' }
 #' @param update number of iterations between potential updates of the sampling
 #' probabilities for method "BAS" or "MCMC+BAS". If NULL do not update, otherwise the
@@ -257,8 +277,16 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' @param force.heredity  Logical variable to force all levels of a factor to be
 #' included together and to include higher order interactions only if lower
 #' order terms are included.  Currently supported with `method='MCMC'`
-#' and experimentally with `method='BAS'` on non-Solaris platforms.
-#' Default is FALSE.
+#' and experimentally with `method='BAS'` on non-Solaris platforms. This is not
+#' compatible currently for enforcing hierachical constraints with orthogonal 
+#' polynomials, poly(x, degree = 3). Without hereditary constraints the number of 
+#' possible models with all possible interactions is 2^2^k where k is the number 
+#' of factors with more than 2 levels.  With hereditary constraints the number of
+#' models is much less, but computing this for k can be quite expensive 
+#' for large k. For the model y ~ x1*x2*x3*x4*x5*x6) there are 7828353 models, 
+#' which is more than 2^22.  With n.models given, this will limit the number of
+#' models to the min(n.models, # models under the heredity constraints)
+#' Default is FALSE currently.
 #' @param pivot Logical variable to allow pivoting of columns when obtaining the
 #' OLS estimates of a model so that models that are not full rank can be fit.
 #' Defaults to TRUE.
@@ -267,9 +295,8 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' @param tol 1e-7 as
 #' @param bigmem Logical variable to indicate that there is access to
 #' large amounts of memory (physical or virtual) for enumeration
-#' with large model spaces, e.g. > 2^25. default; used in determining rank of X^TX in cholesky
-#' decomposition
-#' with pivoting.
+#' with large model spaces, e.g. > 2^25. default; used in determining rank of 
+#' X^TX in cholesky decomposition with pivoting.
 #'
 #' @return \code{bas} returns an object of class \code{bas}
 #'
@@ -355,6 +382,10 @@ normalize.n.models <- function(n.models, p, initprobs, method, bigmem) {
 #' of g-priors for Bayesian Variable Selection. Journal of the American
 #' Statistical Association.  103:410-423.  \cr
 #' \doi{10.1198/016214507000001337}
+#' 
+#' Porwal, A. and Raftery, A. E. (2022) Comparing methods for statistical inference with model uncertainty
+#' PNAS 119 (16) e2120737119
+#' \doi{10.1073/pnas.2120737119} 
 #'
 #' Zellner, A. (1986) On assessing prior distributions and Bayesian regression
 #' analysis with g-prior distributions. In Bayesian Inference and Decision
@@ -584,14 +615,18 @@ bas.lm <- function(formula,
     if (modelprior$family == "Uniform" ||
       modelprior$family == "Bernoulli") {
       warning(
-        "Uniform prior (Bernoulli)  distribution on the Model Space are not recommended for p > n; please consider using tr.beta.binomial or power.prior instead"
+        "Uniform prior (Bernoulli)  distribution on the Model Space are not 
+        recommended for p > n; please consider using tr.beta.binomial or power.prior instead"
       )
     }
+    if (!is.null(n.models)) n.models = min(2^n, n.models)
   }
   if (!is.numeric(initprobs)) {
     if (n <= p && initprobs == "eplogp") {
       stop(
-        "Full model is not full rank so cannot use the eplogp bound to create starting sampling probabilities, perhpas use 'marg-eplogp' for fiting marginal models\n"
+        "Full model is not full rank so cannot use the eplogp bound to create 
+        starting sampling probabilities, use 'marg-eplogp' 
+        for fitting marginal models or specify directly\n"
       )
     }
     initprobs <- switch(
@@ -700,6 +735,12 @@ bas.lm <- function(formula,
       force.heredity <- FALSE
     }
   }
+  
+  if (force.heredity) {
+    # limit the number of models to be enumerated based on Dedekind numbers
+    n.models = count.heredity.models(mf, n.models)
+    }
+
 
   prob <- normalize.initprobs.lm(initprobs, p)
 
